Index: webrtc/logging/rtc_event_log/rtc_event_log_parser.h |
diff --git a/webrtc/logging/rtc_event_log/rtc_event_log_parser.h b/webrtc/logging/rtc_event_log/rtc_event_log_parser.h |
index 1460a4ca8358d4c45720da7469dfd01443f55509..208389398117c6c5aea7329e16c5267d0abb9787 100644 |
--- a/webrtc/logging/rtc_event_log/rtc_event_log_parser.h |
+++ b/webrtc/logging/rtc_event_log/rtc_event_log_parser.h |
@@ -136,11 +136,10 @@ class ParsedRtcEventLog { |
BandwidthUsage* detector_state) const; |
// Reads a audio network adaptation event to a (non-NULL) |
// AudioNetworkAdaptor::EncoderRuntimeConfig struct. Only the fields that are |
// stored in the protobuf will be written. |
- void GetAudioNetworkAdaptation( |
- size_t index, |
- AudioNetworkAdaptor::EncoderRuntimeConfig* config) const; |
+ void GetAudioNetworkAdaptation(size_t index, |
+ AudioEncoderRuntimeConfig* config) const; |
private: |
std::vector<rtclog::Event> events_; |
@@ -136,11 +136,10 @@ class ParsedRtcEventLog { |
BandwidthUsage* detector_state) const; |
// Reads a audio network adaptation event to a (non-NULL) |
- // AudioNetworkAdaptor::EncoderRuntimeConfig struct. Only the fields that are |
+ // AudioEncoderRuntimeConfig struct. Only the fields that are |
// stored in the protobuf will be written. |